@@ -36,6 +36,27 @@
 #define LIBWPS_MAX std::max
 #endif
 
+namespace {
+
+WPXString doubleToString(const double value)
+{
+  WPXString tempString;
+  tempString.sprintf("%.4f", value);
+  std::string decimalPoint(localeconv()->decimal_point);
+  if ((decimalPoint.size() == 0) || (decimalPoint == "."))
+    return tempString;
+  std::string stringValue(tempString.cstr());
+  if (!stringValue.empty())
+  {
+    std::string::size_type pos;
+    while ((pos = stringValue.find(decimalPoint)) != std::string::npos)
+          stringValue.replace(pos,decimalPoint.size(),".");
+  }
+  return WPXString(stringValue.c_str());
+}
+
+} // namespace
+
 _WPSContentParsingState::_WPSContentParsingState() :
 	m_textAttributeBits(0),
 	m_fontSize(12.0f/*WP6_DEFAULT_FONT_SIZE*/), // FIXME ME!!!!!!!!!!!!!!!!!!! HELP WP6_DEFAULT_FONT_SIZE
@@ -602,13 +623,15 @@ void WPSContentListener::_openSpan()
 
 	WPXPropertyList propList;
  	if (attributeBits & WPS_SUPERSCRIPT_BIT) {
-		WPXString sSuperScript;
-		sSuperScript.sprintf("super %f%%", WPS_DEFAULT_SUPER_SUB_SCRIPT);
+		WPXString sSuperScript("super ");
+		sSuperScript.append(doubleToString(WPS_DEFAULT_SUPER_SUB_SCRIPT));
+		sSuperScript.append("%");
 		propList.insert("style:text-position", sSuperScript);
 	}
  	else if (attributeBits & WPS_SUBSCRIPT_BIT) {
-		WPXString sSubScript;
-		sSubScript.sprintf("sub %f%%", WPS_DEFAULT_SUPER_SUB_SCRIPT);
+		WPXString sSubScript("sub ");
+		sSubScript.append(doubleToString(WPS_DEFAULT_SUPER_SUB_SCRIPT));
+		sSubScript.append("%");
 		propList.insert("style:text-position", sSubScript);
 	}
 	if (attributeBits & WPS_ITALICS_BIT)
